SystemOrganization addCategory: #'SqueakSource-Tests'!

TestCase subclass: #SSTestAccessRights
	instanceVariableNames: 'creator admin developer guest other project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SqueakSource-Tests'!

!SSTestAccessRights methodsFor: 'setUp' stamp: 'lr 2/27/2004 19:14'!
setUp
	creator := SSMember initials: 'cr'.
	admin := SSMember initials: 'ad'.
	developer := SSMember initials: 'de'.
	guest := SSMember initials: 'gu'.
	other := SSMember initials: 'ot'.
	
	project := SSProject creator: creator.
	project accessPolicy addAdmin: admin.
	project accessPolicy addDeveloper: developer.
	project accessPolicy addGuest: guest.! !

!SSTestAccessRights methodsFor: 'running' stamp: 'al 7/29/2004 10:21'!
testAccess
	"Test default global read all access right"
	"self run: #testAccess"
	
	self assert: (project isMember: creator allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: creator allowedTo: SSAccessPolicy write).
	self assert: (project isMember: creator allowedTo: SSAccessPolicy read).
	
	self assert: (project isMember: admin allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: admin allowedTo: SSAccessPolicy write).
	self assert: (project isMember: admin allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: developer allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: developer allowedTo: SSAccessPolicy write).
	self assert: (project isMember: developer allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: guest allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: guest allowedTo: SSAccessPolicy write).
	self assert: (project isMember: guest allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: other allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: other allowedTo: SSAccessPolicy write).
	self assert: (project isMember: other allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: nil allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: nil allowedTo: SSAccessPolicy write).
	self assert: (project isMember: nil allowedTo: SSAccessPolicy read).
	
	self 
		should: [ project isMember: admin allowedTo: #zork ] 
		raise: Error.
	
	project admins: (project admins copyWithout: creator).
	self deny: (project isMember: creator allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: creator allowedTo: SSAccessPolicy write).
	self assert: (project isMember: creator allowedTo: SSAccessPolicy read).
! !

!SSTestAccessRights methodsFor: 'running' stamp: 'al 7/29/2004 10:19'!
testAccessNoAccess
	"self run: #testAccessNoAccess"
	
	project globalRight: SSAccessPolicy allowNothing.
	
	self assert: (project isMember: creator allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: creator allowedTo: SSAccessPolicy write).
	self assert: (project isMember: creator allowedTo: SSAccessPolicy read).
	
	self assert: (project isMember: admin allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: admin allowedTo: SSAccessPolicy write).
	self assert: (project isMember: admin allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: developer allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: developer allowedTo: SSAccessPolicy write).
	self assert: (project isMember: developer allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: guest allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: guest allowedTo: SSAccessPolicy write).
	self assert: (project isMember: guest allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: other allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: other allowedTo: SSAccessPolicy write).
	self deny: (project isMember: other allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: nil allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: nil allowedTo: SSAccessPolicy write).
	self deny: (project isMember: nil allowedTo: SSAccessPolicy read).
	
	self 
		should: [ project isMember: admin allowedTo: #zork ] 
		raise: Error.
	
	project admins: (project admins copyWithout: creator).
	self deny: (project isMember: creator allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: creator allowedTo: SSAccessPolicy write).
	self deny: (project isMember: creator allowedTo: SSAccessPolicy read).
! !

!SSTestAccessRights methodsFor: 'running' stamp: 'lr 2/27/2004 19:17'!
testGlobalAccess
	"self run: #testGlobalAccess"
	
	project globalRight: SSAccessPolicy allowAllRead.
	
	self deny: (project isMember: other allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: other allowedTo: SSAccessPolicy write).
	self assert: (project isMember: other allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: nil allowedTo: SSAccessPolicy admin).
	self deny: (project isMember: nil allowedTo: SSAccessPolicy write).
	self assert: (project isMember: nil allowedTo: SSAccessPolicy read).
	
	project globalRight: SSAccessPolicy allowAllWrite.
	
	self deny: (project isMember: other allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: other allowedTo: SSAccessPolicy write).
	self assert: (project isMember: other allowedTo: SSAccessPolicy read).
	
	self deny: (project isMember: nil allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: nil allowedTo: SSAccessPolicy write).
	self assert: (project isMember: nil allowedTo: SSAccessPolicy read).
	! !

!SSTestAccessRights methodsFor: 'running' stamp: 'pmm 10/8/2007 20:27'!
testInitialization
	"self run: #testInitialization"
	
	self deny: project accessPolicy isNil.
	
	self assert: project creator = creator.
	
	self assert: (project admins includesAllOf: (Array with: creator with: admin)).
	self assert: project admins size = 2.
	
	self assert: (project developers includes: developer).
	self assert: project developers size = 1.
	
	self assert: (project guests includes: guest).
	self assert: project guests size = 1.
	
	self assert: project globalRight = SSAccessPolicy allowAllRead
	
	
	! !

!SSTestAccessRights methodsFor: 'running' stamp: 'lr 2/27/2004 19:19'!
testSuperuser
	"self run: #testSuperuser"
	
	| superuser |
	superuser := (SSMember initials: 'su') superuser: true.
	self assert: superuser isSuperUser.
	
	project globalRight: SSAccessPolicy allowAllRead.
	self assert: (project isMember: superuser allowedTo: SSAccessPolicy admin).
	self assert: (project isMember: superuser allowedTo: SSAccessPolicy read).
	self assert: (project isMember: superuser allowedTo: SSAccessPolicy write).
	
	! !
